@@ -1,14 +1,30 @@
+//! Irq module deals with interrupt handling.
+//! 
+//! In this module you will find functions that help
+//! manaage interrupts. Here is an example of enabling
+//! interrupts for the periodic timer:
+//! 
+//! ```no_run
+//! use teensycore::phys::irq::*;
+//! 
+//! irq_attach(Irq::PeriodicTimer, handle_timer_irq);
+//! irq_enable(Irq::PeriodicTimer);
+//! 
+//! fn handle_timer_irq() {
+//! 
+//! }
+//! ``` 
 #![allow(dead_code)]
 
 type Fn = fn();
 use core::arch::asm;
-use crate::phys::{ 
+use crate::{phys::{ 
     addrs,
     assign,
     assign_8,
     read_word,
     set_bit,
- };
+ }, assembly};
 
 // On the teensy, it's actually closer to 158 interrupts
 // This will be adjusted in the future.
@@ -75,40 +91,43 @@ static mut IRQ_DISABLE_COUNT: usize = 0;
 
 /// System-level command to resume processing interrupts
 /// across the device.
+/// 
 pub fn enable_interrupts() {
     unsafe {
         if IRQ_DISABLE_COUNT > 0 {
             IRQ_DISABLE_COUNT -= 1;
         }
+    }
 
-        if IRQ_DISABLE_COUNT == 0 {
-            asm!("CPSIE i");
-        }
+    if unsafe { IRQ_DISABLE_COUNT } == 0 {
+        assembly!("CPSIE i");            
     }
 }
 
 /// System-level command to stop processing interrupts
 /// across the device.
+/// 
 pub fn disable_interrupts() {
     unsafe {
         IRQ_DISABLE_COUNT += 1;
-        asm!("CPSID i");
     }
+    
+    assembly!("CPSID i");
 }
 
 /// Return the current address stored
 /// in the NVIC
-pub fn irq_addr() -> u32 {
+fn irq_addr() -> u32 {
     return read_word(0xe000ed08);
 }
 
 /// Return the total size of the IVT
-pub fn irq_size() -> u32 {
+fn irq_size() -> u32 {
     return core::mem::size_of::<IrqTable>() as u32;
 }
 
 /// Get the current IVT wherever it may be stored
-pub fn get_ivt() -> *mut IrqTable {
+fn get_ivt() -> *mut IrqTable {
     return irq_addr() as *mut IrqTable
 }
 
@@ -167,7 +186,7 @@ the NVIC has the value I think it has.
 Spent like 20 hours debugging this. I am so done
 with magic memory locations changing around.
 */
-pub fn update_ivt() {
+fn update_ivt() {
     let ivt = get_ivt();
     unsafe {
         // We have no idea here
@@ -237,13 +256,11 @@ pub fn irq_attach(irq_number: Irq, func: Fn) {
 /// Some kind of hard-fault, typically
 /// this is a catastrophic function that hangs
 /// the program.
-pub fn fault_handler() {
+fn fault_handler() {
     crate::err(crate::PanicType::Hardfault);
 }
 
 /// An un-implemented interrupt
-pub fn noop() {
-    unsafe {
-        asm!("nop");
-    }
+fn noop() {
+    assembly!("nop");
 }
\ No newline at end of file
