@@ -1,5 +1,7 @@
-pub mod map;
-pub mod strings;
+pub mod boxed;
 pub mod buffer;
+pub mod closure;
+pub mod map;
+pub mod observable;
+pub mod strings;
 pub mod vector;
-pub mod observable;
\ No newline at end of file
